from setuptools import setup, find_packages

def readfile(name):
    with open(name) as f:
        return f.read()

readme = readfile('README.rst')
changes = readfile('CHANGES.rst')

requires = [
    'virtualenv',
]

tests_require = [
    'pytest',
    'pytest-cov',
]

setup(
    name='pytest-venv',
    version='0.1.1',
    description='py.test fixture for creating a virtual environment',
    long_description=readme + '\n\n' + changes,
    author='Michael Merickel',
    author_email='michael@merickel.org',
    url='https://github.com/mmerickel/pytest-venv',
    packages=find_packages('src', exclude=['tests']),
    package_dir={'': 'src'},
    include_package_data=True,
    install_requires=requires,
    extras_require={
        'testing': tests_require,
    },
    zip_safe=False,
    keywords='',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: Pytest',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Topic :: Software Development :: Testing',
    ],
    entry_points={
        'pytest11': [
            'venv = pytest_venv',
        ],
    },
)



import os
import pytest
import sys
import subprocess

WIN = sys.platform == 'win32'


@pytest.fixture
def venv(tmpdir):
    venv = VirtualEnvironment(tmpdir.strpath)
    venv.create()
    yield venv


class VirtualEnvironment(object):
    def __init__(self, path):
        self.path = path
        self.bin = os.path.join(
            self.path,
            'bin' if sys.platform != 'win32' else 'Scripts',
        )
        self.python = os.path.join(self.bin, 'python')

    def create(self, system_packages=False):
        cmd = [sys.executable, '-m', 'virtualenv']
        cmd += ['-p', sys.executable]
        if system_packages:
            cmd += ['--system-site-packages']
        cmd += [self.path]
        subprocess.check_call(cmd)

    def install(self, pkg_name, editable=False, upgrade=False):
        cmd = [self.python, '-m', 'pip', 'install']
        if upgrade:
            cmd += ['-U']
        if editable:
            cmd += ['-e']
        cmd += [pkg_name]
        subprocess.check_call(cmd)



import sys
import subprocess

def test_it(venv):
    result = subprocess.check_output(
        [venv.python, '-c', 'print("hello world")'],
    )
    assert b'hello world' in result

def test_it_installs_dep(venv):
    venv.install('pyramid')
    subprocess.check_call([venv.python, '-c', 'import pyramid'])

def test_it_uses_correct_python(venv):
    result = subprocess.check_output(
        [venv.python, '-c', 'import sys; print(sys.version)'],
    )
    assert result.decode('utf8').strip() == str(sys.version)
